import distutils.version
import os
import sys
import warnings

from gym import error
from gym.utils import reraise
from gym.version import VERSION as __version__

from gym.core import Env, GoalEnv, Space, Wrapper, ObservationWrapper, ActionWrapper, RewardWrapper
from gym.envs import make, spec
from gym import wrappers, spaces, logger

def undo_logger_setup():
    warnings.warn("gym.undo_logger_setup is deprecated. gym no longer modifies the global logging configuration")

__all__ = ["Env", "Space", "Wrapper", "make", "spec", "wrappers"]



import gym
import numpy as np

class MultiBinary(gym.Space):
    def __init__(self, n):
        self.n = n
        gym.Space.__init__(self, (self.n,), np.int8)
    def sample(self):
        return gym.spaces.np_random.randint(low=0, high=2, size=self.n).astype(self.dtype)
    def contains(self, x):
        return ((x==0) | (x==1)).all()
    def to_jsonable(self, sample_n):
        return np.array(sample_n).tolist()
    def from_jsonable(self, sample_n):
        return [np.asarray(sample) for sample in sample_n]